==> bokeh-0.12.10-py27_0.tar.bz2: Lib/site-packages/bokeh/__main__.py <==
#-----------------------------------------------------------------------------
# Copyright (c) 2012 - 2017, Anaconda, Inc. All rights reserved.
#
# Powered by the Bokeh Development Team.
#
# The full license is in the file LICENSE.txt, distributed with this software.
#-----------------------------------------------------------------------------
''' Enable execution of the "bokeh" command line program with the ``-m``
switch. For example:

.. code-block:: sh

    python -m bokeh serve --show app.py

is equivalent to

.. code-block:: sh

    bokeh serve --show app.py

'''

#-----------------------------------------------------------------------------
# Boilerplate
#-----------------------------------------------------------------------------
from __future__ import absolute_import, division, print_function, unicode_literals

import logging
log = logging.getLogger(__name__)

from bokeh.util.api import public, internal ; public, internal

#-----------------------------------------------------------------------------
# Public API
#-----------------------------------------------------------------------------

__all__ = (
    'main',
)

def main():
    ''' Execute the "bokeh" command line program.

    '''
    import sys
    from bokeh.command.bootstrap import main as _main

   # Main entry point (see setup.py)
    _main(sys.argv)

#-----------------------------------------------------------------------------
# Code
#-----------------------------------------------------------------------------

if __name__ == "__main__":
    main()

==> bokeh-1.0.2-py27_1000.tar.bz2: Lib/site-packages/bokeh/__main__.py <==
#-----------------------------------------------------------------------------
# Copyright (c) 2012 - 2018, Anaconda, Inc. All rights reserved.
#
# Powered by the Bokeh Development Team.
#
# The full license is in the file LICENSE.txt, distributed with this software.
#-----------------------------------------------------------------------------
''' Enable execution of the "bokeh" command line program with the ``-m``
switch. For example:

.. code-block:: sh

    python -m bokeh serve --show app.py

is equivalent to

.. code-block:: sh

    bokeh serve --show app.py

'''

#-----------------------------------------------------------------------------
# Boilerplate
#-----------------------------------------------------------------------------
from __future__ import absolute_import, division, print_function, unicode_literals

import logging
log = logging.getLogger(__name__)

#-----------------------------------------------------------------------------
# Imports
#-----------------------------------------------------------------------------

# Standard library imports

# External imports

# Bokeh imports

#-----------------------------------------------------------------------------
# Globals and constants
#-----------------------------------------------------------------------------

__all__ = (
    'main',
)

#-----------------------------------------------------------------------------
# General API
#-----------------------------------------------------------------------------

#-----------------------------------------------------------------------------
# Dev API
#-----------------------------------------------------------------------------

def main():
    ''' Execute the "bokeh" command line program.

    '''
    import sys
    from bokeh.command.bootstrap import main as _main

   # Main entry point (see setup.py)
    _main(sys.argv)

#-----------------------------------------------------------------------------
# Private API
#-----------------------------------------------------------------------------

#-----------------------------------------------------------------------------
# Code
#-----------------------------------------------------------------------------

if __name__ == "__main__":
    main()
